/**
  *  \file int/if/msgif.h
  *  \brief Interpreter Game Interface: Messages
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_INT_IF_MSGIF_H
#define PCC_V2_INT_IF_MSGIF_H

#include <vector>
#include "cpluslib/string.h"
#include "cpluslib/smartptr.h"
#include "int/context.h"
#include "game/msgparse.h"      // GMessageLines
#include "int/args.h"

class GMessagebox;

IntValue*   IFInmsgGet(IntArgBlock& args);
IntContext* IFInmsgMake();
int32_t     IFInmsgDim(int32_t dim);

/** Message context. */
class IntMessageContext : public IntContext {
 protected:
    GMessagebox& mbox;
    int nr;

 private:
    Ptr<GMessageLines> line_cache;

    void createLineCache();
 public:
    IntMessageContext(GMessagebox& mbox, int nr);
    ~IntMessageContext();

    virtual int mapId(int nr) = 0;

    // IntContext:
    int32_t   lookup(const IntNameQuery& name);
    void      set(int32_t index, IntValue* value);
    IntValue* get(int32_t index);
    bool      next();
    GObject*  getObject();
    void      enumProperties(IntPropertyAcceptor& acceptor);

    // IntValue:
    string_t  toString(bool readable);
    void      store(IntTagNode& sv, Stream& aux);
};

#endif
