/**
  *  \file ui/widgets/checkbox.cc
  *  \brief UICheckbox widget
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "ui/widgets/checkbox.h"
#include "resmgr/resmgr.h"

/** Create checkbox.
    \param aid    Widget id
    \param aname  Text
    \param akey   Hotkey
    \param max    Number of states (2 if "yes/no"). Clicking brings
                  the checkbox through the states max-1, max-2, ... 0 */
UICheckbox::UICheckbox(int aid, string_t aname, UIKey akey, int max)
    : UIAbstractCheckbox(aid, aname, akey), value(0), max(max)
{ }

UICheckbox::~UICheckbox()
{ }

void
UICheckbox::click(int)
{
    int i = getValue();
    if (i == 0)
        i = max;
    setValue(i-1);
    setFocusedWidget();
}

void
UICheckbox::setValue(int avalue)
{
    if (value != avalue) {
        value = avalue;
        drawWidget(false);
        sig_changed.raise(getId());
    }
}

Ptr<GfxPixmap>
UICheckbox::getPixmap()
{
    return requestPixmap(ResId("cb", getValue()+1));
}
