/**
  *  \file ui/widgets/dircrumbs.h
  *  \brief UIDirectoryCrumbTrail widget
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_UI_WIDGETS_DIRCRUMBS_H
#define PCC_V2_UI_WIDGETS_DIRCRUMBS_H

#include <vector>
#include "io/dirs.h"
#include "ui/iconbox.h"

/** Directory Crumb Navigation Widget.
    Displays a list of directory components for "crumb navigation".
    A directory "/home/user/vgap" is represented using five elements:
    "[Places]" (to select roots, i.e. drive letters), "/", "home",
    "user", "vgap" (to select these directories). */
class UIDirectoryCrumbTrail : public UIIconBox {
 public:
    UIDirectoryCrumbTrail();
    ~UIDirectoryCrumbTrail();

    int  getItemWidth(int number);
    int  getNumberOfItems();
    void drawItem(int number, GfxCanvas& can, const GfxRect& r, ItemState state);

    void setDirectory(Ptr<Directory> dir);

    Ptr<Directory> getItem(int number);

 private:
    /** All directories on this path, in reverse order. When the current directory is
        "/home/user/vgap", this contains
        - /home/user/vgap
        - /home/user
        - /home
        - /
        in this order. */
    std::vector<Ptr<Directory> > dirs;

    string_t getTextOf(int number);
};

#endif
